"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const microservice_1 = require("@jfrog-pipelines/microservice");
const utility_1 = require("@jfrog-pipelines/utility");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const types_1 = require("@jfrog-pipelines/types");
const v1_1 = require("./routes/v1");
const NodeVersionUpgradeInitializer_1 = require("./NodeVersionUpgradeInitializer");
const NodePoolWorker_1 = require("./NodePoolWorker");
const logLevel = 'info';
const QUEUE_NAME = 'core.nodePoolService';
const serviceEnum = 11;
const serviceDetails = utility_1.ServiceMeta[serviceEnum];
const options = {
    enum: serviceEnum,
    initializers: [new microservice_1.AmqpClientInitializer(), new NodeVersionUpgradeInitializer_1.NodeVersionUpgradeInitializer()],
    healthChecks: [],
    logLevel: logLevel,
    models: [data_access_layer_1.BuildPlaneMessage, data_access_layer_1.Lock, data_access_layer_1.Node, data_access_layer_1.NodePool, data_access_layer_1.SystemConfig, data_access_layer_1.NodeStats, data_access_layer_1.BuildPlaneImages, data_access_layer_1.NodeConsole],
    productHome: process.env.APP_CONFIG_PATH,
    validator: new microservice_1.DefaultApplicationValidator([], []),
    isAccessEnabled: true,
    apiRoutes: {
        serverPrefix: 'api/v1',
        routes: v1_1.nodepoolRoutesV1,
        schemas: [types_1.NodeStatsResponseSchema, types_1.NodeConsoleResponseSchema, types_1.MachineImageResponseSchema],
        documentation: {
            title: 'nodepool-service',
            description: 'NodePool Microservice open apis 3',
            version: '1.0.0'
        }
    }
};
async function startApp() {
    const app = new microservice_1.Application(options, microservice_1.applicationContext);
    const poolWorker = new NodePoolWorker_1.NodePoolWorker(serviceDetails, microservice_1.applicationContext);
    await app.listen(QUEUE_NAME, poolWorker);
}
void startApp();
//# sourceMappingURL=app.js.map